aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/render
diff options
context:
space:
mode:
Diffstat (limited to 'src/java/org/apache/fop/render')
-rw-r--r--src/java/org/apache/fop/render/afp/modca/Registry.java30
1 files changed, 5 insertions, 25 deletions
diff --git a/src/java/org/apache/fop/render/afp/modca/Registry.java b/src/java/org/apache/fop/render/afp/modca/Registry.java
index ae32654de..62d2f26f9 100644
--- a/src/java/org/apache/fop/render/afp/modca/Registry.java
+++ b/src/java/org/apache/fop/render/afp/modca/Registry.java
@@ -149,7 +149,7 @@ public final class Registry {
private byte componentId;
private byte[] oid;
private String name;
- private boolean canBeIncluded;
+ private boolean includable;
private String mimeType;
/**
@@ -158,13 +158,13 @@ public final class Registry {
* @param componentId the component id of this object type
* @param oid the object id of this object type
* @param name the object type name
* @param canBeIncluded true if this object can be included with an IOB structured field
* @param mimeType the mime type associated with this object type
*/
public ObjectType(byte componentId, byte[] oid, String name,
- boolean canBeIncluded, String mimeType) {
+ boolean includable, String mimeType) {
this.name = name;
- this.canBeIncluded = canBeIncluded;
+ this.includable = includable;
this.mimeType = mimeType;
this.componentId = componentId;
this.oid = oid;
@@ -204,7 +204,7 @@ public final class Registry {
* @return true if this component can be included with an IOB structured field
*/
public boolean canBeIncluded() {
- return this.canBeIncluded;
+ return this.includable;
}
/**
@@ -216,26 +216,6 @@ public final class Registry {
return this.mimeType;
}
- /**
- * Returns true if this is an image type
- *
- * @return true if this is an image type
- */
- public boolean isImage() {
- return mimeType == MimeConstants.MIME_TIFF
- || mimeType == MimeConstants.MIME_GIF
- || mimeType == MimeConstants.MIME_JPEG;
- }
-
- /**
- * Returns true if this is a graphic type
- *
- * @return true if this is a graphic type
- */
- public boolean isGraphic() {
- return mimeType == MimeConstants.MIME_SVG;
- }
-
/** {@inheritDoc} */
public String toString() {
return this.getName();
@@ -158,13 +158,13 @@ public final class Registry {
* @param oid the object id of this object type
* @param name the object type name
- * @param canBeIncluded true if this object can be included with an IOB structured field
+ * @param includable true if this object can be included with an IOB structured field
* @param mimeType the mime type associated with this object type
*/